# -*- coding: utf-8 -*-

from setuptools import setup

setup(
    name='pysharperratio',
    version='0.01.07',
    description='A moment-free estimator of the Sharpe (signal-to-noise) ratio.',
    long_description=open('README.rst').read(),
    author='Amir Sani',
    url='http://www.amirsani.com',
    author_email='reachme@amirsani.com',
    download_url='https://github.com/amirsani/pySharpeRratio',
    packages=['pysharperratio'],
    zip_safe=False
)
